(howto)=

# **How-To**

This section shows you how to use crowsetta for specific tasks.

```{toctree}
:maxdepth: 1

howto/howto-user-format
howto/convert-generic-seq
howto/convert-simple-seq
howto/remove-silent-labels-textgrid
```
